#! /usr/bin/env python3
# Count CyBOK KA codes in CSV

import csv
import seaborn as sns
import matplotlib.pyplot as plt
from sys import argv
from collections import Counter
from os.path import basename

def csv_data(filename):
    """Read the CSV in the FILENAME, and yield each row."""
    with open(filename) as f:
        data = csv.DictReader(f)
        for row in data:
            yield row

def count_column(filename, column):
    """Count all the different elements in a COLUMN of the CSV FILENAME."""
    counter = Counter()
    for row in csv_data(filename):
        counter[row[column]] += 1
    return counter

# Each of the CyBOK Knowledge Areas
CYBOK_KAS = ['INTRO',
             'RMG', 'LR', 'HF', 'POR',
             'MAT', 'AB', 'SOIM', 'F',
             'C', 'OSV', 'DSS', 'FMS', 'AAA',
             'SS', 'WAM', 'SSL',
             'AC', 'NS', 'HS', 'CPS', 'PLT',
             '-']

def cybok_bar(counts, outfile):
    """Create a bar chart of the COUNTS using the CyBOK knowledge areas, and write out to OUTFILE."""
    fig = plt.figure()
    data = [counts[ka] for ka in CYBOK_KAS]
    plt.bar(CYBOK_KAS, data)
    plt.xlabel("CyBOK KA")
    plt.xticks(rotation=90)
    plt.ylabel("Count")
    plt.savefig(outfile)
    
            
if __name__ == '__main__':
    sns.set_theme()
    for arg in argv[1:]:
        counts = count_column(arg, 'KA')
        cybok_bar(counts, f'{basename(arg).split(".", 1)[0]}.png')
